@@ -678,7 +678,11 @@ QString getMiKTeXBinPathReal()
 		foreach (const QString &p, QDir(d).entryList(QStringList(), QDir::AllDirs, QDir::Time))
 			if (p.toLower().contains("miktex") && QDir(d + addPathDelimeter(p) + "miktex\\bin\\").exists())
 				return d + addPathDelimeter(p) + "miktex\\bin\\";
-	static const QStringList candidates = QStringList() << "C:\\miktex\\miktex\\bin" << "C:\\tex\\texmf\\miktex\\bin" << "C:\\miktex\\bin";
+	static const QStringList candidates = QStringList() << "C:\\miktex\\miktex\\bin"
+														<< "C:\\tex\\texmf\\miktex\\bin"
+														<< "C:\\miktex\\bin"
+														<< QString(getenv("LOCALAPPDATA")) + "\\Programs\\MiKTeX 2.9\\miktex\\bin";
+
 	foreach (const QString &d, candidates)
 		if (QDir(d).exists())
 			return d + "\\";
@@ -2167,7 +2171,7 @@ void ProcessX::startCommand()
 	QByteArray path = qgetenv("PATH");
 #ifdef Q_OS_OSX
 	QString basePath = getEnvironmentPath();
-	qputenv("PATH", path + getPathListSeparator().toLatin1() + BuildManager::resolvedAdditionalSearchPaths().toUtf8() + getPathListSeparator().toLatin1() + basePath.toUtf8());
+    qputenv("PATH", path + getPathListSeparator().toLatin1() + BuildManager::resolvePaths(BuildManager::additionalSearchPaths).toUtf8() + getPathListSeparator().toLatin1() + basePath.toUtf8());
 	// needed for searching the executable in the additional paths see https://bugreports.qt-project.org/browse/QTBUG-18387
 #else
 	qputenv("PATH", path + getPathListSeparator().toLatin1() + BuildManager::resolvePaths(BuildManager::additionalSearchPaths).toUtf8()); // needed for searching the executable in the additional paths see https://bugreports.qt-project.org/browse/QTBUG-18387
