@@ -7,16 +7,24 @@ GrammarError::GrammarError(int offset, int length, const GrammarErrorType &error
 GrammarError::GrammarError(int offset, int length, const GrammarError &other): offset(offset), length(length), error(other.error), message(other.message), corrections(other.corrections) {}
 
 GrammarCheck::GrammarCheck(QObject *parent) :
-	QObject(parent), backend(0), ticket(0), pendingProcessing(false), shuttingDown(false)
+	QObject(parent), ltstatus(LTS_Unknown), backend(0), ticket(0), pendingProcessing(false), shuttingDown(false)
 {
 	latexParser = new LatexParser();
 }
-
+/*!
+ * \brief GrammarCheck::~GrammarCheck
+ * Destructor
+ */
 GrammarCheck::~GrammarCheck()
 {
 	if (latexParser) delete latexParser;
 }
-
+/*!
+ * \brief GrammarCheck::init
+ * initialize grammar checker
+ * \param lp reference to latex parser
+ * \param config reference to config
+ */
 void GrammarCheck::init(const LatexParser &lp, const GrammarCheckerConfig &config)
 {
 	*latexParser = lp;
@@ -42,7 +50,12 @@ void GrammarCheck::init(const LatexParser &lp, const GrammarCheckerConfig &confi
 	languageMapping.insert("sv-SV", "sv");
 }
 
-
+/*!
+ * \brief readWordList
+ * Read bad words/stop words from file
+ * \param file
+ * \return word list as set
+ */
 QSet<QString> readWordList(const QString &file)
 {
 	QFile f(file);
@@ -210,11 +223,11 @@ void GrammarCheck::process(int reqId)
 
 			if (type == LatexReader::NW_TEXT) tb.words << lr.word;
 			else { /*if (type == LatexReader::NW_PUNCTATION) */
-				if (lr.word == "-" && !tb.words.isEmpty()) {
+                if ((lr.word == "-" || lr.word == "~" )&& !tb.words.isEmpty()) {
 					//- can either mean a word-separator or a sentence -- separator
 					// => if no space, join the words at both sides of the - (this could be easier handled in nextToken, but spell checking usually doesn't support - within words)
 					if (lr.wordStartIndex == tb.endindices.last()) {
-						tb.words.last() += '-';
+                        tb.words.last() += lr.word;
 						tb.endindices.last()++;
 
 						int tempIndex = lr.index;
@@ -258,6 +271,11 @@ void GrammarCheck::process(int reqId)
 	}
 
 	bool backendAvailable = backend->isAvailable();
+	LTStatus newstatus = backendAvailable ? LTS_Working : LTS_Error;
+	if (newstatus != ltstatus) {
+		ltstatus = newstatus;
+		emit languageToolStatusChanged();
+	}
 
 	QList<TokenizedBlock> crBlocks = cr.blocks; //cr itself might become invalid during the following loop
 	int crTicket = cr.ticket;
@@ -267,15 +285,15 @@ void GrammarCheck::process(int reqId)
 		const TokenizedBlock &tb = crBlocks.at(b);
 		if (tb.words.isEmpty() || !backendAvailable) backendChecked(crTicket, b, QList<GrammarError>(), true);
 		else  {
-			QString joined;
 			const QStringList &words = tb.words;
+            QString joined;
 			int expectedLength = 0;
 			foreach (const QString & s, words) expectedLength += s.length();
-			joined.reserve(expectedLength + words.length());
-			for (int i = 0;;) {
-				joined += words[i];
-				CHECK_FOR_SPACE_AND_CONTINUE_LOOP(i, words);
-				joined += " ";
+            joined.reserve(expectedLength + words.length());
+            for (int i = 0;;) {
+                joined += words[i];
+                CHECK_FOR_SPACE_AND_CONTINUE_LOOP(i, words);
+                joined += " ";
 			}
 			backend->check(crTicket, b, crLanguage, joined);
 		}
@@ -321,8 +339,8 @@ void GrammarCheck::backendChecked(uint crticket, int subticket, const QList<Gram
 	QMap<QString, LanguageGrammarData>::const_iterator it = languages.constFind(cr.language);
 	if (it == languages.constEnd()) {
 		LanguageGrammarData lgd;
-		lgd.stopWords = readWordList(config.wordlistsDir + "/" + cr.language + ".stopWords");
-		lgd.badWords = readWordList(config.wordlistsDir + "/" + cr.language + ".badWords");
+        lgd.stopWords = readWordList(config.wordlistsDir + "/" + languageFromLanguageToolToHunspell(cr.language) + ".stopWords");
+        lgd.badWords = readWordList(config.wordlistsDir + "/" + languageFromLanguageToolToHunspell(cr.language) + ".badWords");
 		languages.insert(cr.language, lgd);
 		it = languages.constFind(cr.language);
 	}
@@ -346,7 +364,12 @@ void GrammarCheck::backendChecked(uint crticket, int subticket, const QList<Gram
 
 			//check words
 			bool realCheck = true; //cr.lines[w] >= cr.linesToSkipDelta;
+			int truncatedChars = 0;
 			QString normalized = words[w].toLower();
+			if (normalized.endsWith('.')) {
+				normalized = normalized.left(normalized.length() -1);
+				truncatedChars =  1;
+			}
 			if (ld.stopWords.contains(normalized)) {
 				if (checkLastWord) {
 					if (prevSW == normalized)
@@ -360,7 +383,7 @@ void GrammarCheck::backendChecked(uint crticket, int subticket, const QList<Gram
 				if (lastSeen > -1) {
 					int delta = totalWords - lastSeen;
 					if (delta <= MAX_REP_DELTA)
-						cr.errors[tb.lines[w]] << GrammarError(tb.indices[w], tb.endindices[w] - tb.indices[w], GET_WORD_REPETITION, tr("Word repetition. Distance %1").arg(delta), QStringList() << "");
+						cr.errors[tb.lines[w]] << GrammarError(tb.indices[w], tb.endindices[w] - tb.indices[w] - truncatedChars, GET_WORD_REPETITION, tr("Word repetition. Distance %1").arg(delta), QStringList() << "");
 					else if (config.maxRepetitionLongRangeDelta > config.maxRepetitionDelta && delta <= config.maxRepetitionLongRangeDelta && normalized.length() >= config.maxRepetitionLongRangeMinWordLength)
 						cr.errors[tb.lines[w]] << GrammarError(tb.indices[w], tb.endindices[w] - tb.indices[w], GET_LONG_RANGE_WORD_REPETITION, tr("Long range word repetition. Distance %1").arg(delta), QStringList() << "");
 				}
@@ -433,6 +456,18 @@ QString GrammarCheck::languageFromHunspellToLanguageTool(QString language)
 	return languageMapping.value(language, language);
 }
 
+/*!
+ * Reformats a language identifier from the LanguageTool notation to hunspell notation
+ * e.g. en-GB -> en_GB and it -> it
+ */
+QString GrammarCheck::languageFromLanguageToolToHunspell(QString language)
+{
+    if(languageMapping.values().contains(language)){
+        language=languageMapping.key(language);
+    }
+    language.replace('-', '_');
+    return language;
+}
 
 
 GrammarCheckBackend::GrammarCheckBackend(QObject *parent): QObject(parent) {}
@@ -449,7 +484,7 @@ struct CheckRequestBackend {
 	CheckRequestBackend(int ti, int st, const QString &la, const QString &te): ticket(ti), subticket(st), language(la), text(te) {}
 };
 
-GrammarCheckLanguageToolSOAP::GrammarCheckLanguageToolSOAP(QObject *parent): GrammarCheckBackend(parent), nam(0), connectionAvailability(false), triedToStart(false), firstRequest(true)
+GrammarCheckLanguageToolSOAP::GrammarCheckLanguageToolSOAP(QObject *parent): GrammarCheckBackend(parent), nam(0), connectionAvailability(Unknown), triedToStart(false), firstRequest(true)
 {
 
 }
@@ -458,13 +493,14 @@ GrammarCheckLanguageToolSOAP::~GrammarCheckLanguageToolSOAP()
 {
 	if (nam) delete nam;
 }
-
+/*!
+ * \brief GrammarCheckLanguageToolSOAP::init
+ * Initialize LanguageTool as grammar backend
+ * \param config reference to config
+ */
 void GrammarCheckLanguageToolSOAP::init(const GrammarCheckerConfig &config)
 {
-	if (!nam) {
-		nam = new QNetworkAccessManager();
-		connect(nam, SIGNAL(finished(QNetworkReply *)), SLOT(finished(QNetworkReply *)));
-	}
+
 	server = config.languageToolURL;
 	ltPath = config.languageToolAutorun ? config.languageToolPath : "";
 	if (!ltPath.endsWith("jar")) {
@@ -476,13 +512,14 @@ void GrammarCheckLanguageToolSOAP::init(const GrammarCheckerConfig &config)
 				break;
 			}
 	}
+	ltArguments = config.languageToolArguments;
 	javaPath = config.languageToolJavaPath;
 
 	ignoredRules.clear();
 	foreach (const QString &r, config.languageToolIgnoredRules.split(","))
 		ignoredRules << r.trimmed();
-	connectionAvailability = 0;
-	if (config.languageToolURL.isEmpty()) connectionAvailability = -1;
+	connectionAvailability = Unknown;
+	if (config.languageToolURL.isEmpty()) connectionAvailability = Broken;
 	triedToStart = false;
 	firstRequest = true;
 
@@ -496,10 +533,13 @@ void GrammarCheckLanguageToolSOAP::init(const GrammarCheckerConfig &config)
 		specialRules << temp;
 	}
 }
-
+/*!
+ * \brief GrammarCheckLanguageToolSOAP::isAvailable
+ * \return LanguageTool is available (or possibly so)
+ */
 bool GrammarCheckLanguageToolSOAP::isAvailable()
 {
-	return connectionAvailability >= 0;
+	return connectionAvailability == Unknown || connectionAvailability == WorkedAtLeastOnce;
 }
 
 QString quoteSpaces(const QString &s)
@@ -507,12 +547,15 @@ QString quoteSpaces(const QString &s)
 	if (!s.contains(' ')) return s;
 	return '"' + s + '"';
 }
-
+/*!
+ * \brief GrammarCheckLanguageToolSOAP::tryToStart
+ * try to start LanguageTool-Server on local machine
+ */
 void GrammarCheckLanguageToolSOAP::tryToStart()
 {
 	if (triedToStart) {
 		if (QDateTime::currentDateTime().toTime_t() - startTime < 60 * 1000 ) {
-			connectionAvailability = 0;
+			connectionAvailability = Unknown;
 			ThreadBreaker::sleep(1);
 		}
 		return;
@@ -524,11 +567,10 @@ void GrammarCheckLanguageToolSOAP::tryToStart()
 	connect(javaProcess, SIGNAL(finished(int)), javaProcess, SLOT(deleteLater()));
 	connect(this, SIGNAL(destroyed()), javaProcess, SLOT(deleteLater()));
 
-	javaProcess->start(quoteSpaces(javaPath) + " -cp " + quoteSpaces(ltPath) + "  org.languagetool.server.HTTPServer -p " + QString::number(server.port(8081)));
-	//qDebug() <<javaPath + " -cp "+ltPath+ "  org.languagetool.server.HTTPServer";
+	javaProcess->start(quoteSpaces(javaPath) + " -cp " + quoteSpaces(ltPath) + "  " + ltArguments);
 	javaProcess->waitForStarted();
 
-	connectionAvailability = 0;
+	connectionAvailability = Unknown;
 	startTime = QDateTime::currentDateTime().toTime_t(); //TODO: fix this in year 2106 when hopefully noone uses qt4.6 anymore
 }
 
@@ -536,16 +578,28 @@ const QNetworkRequest::Attribute AttributeTicket = (QNetworkRequest::Attribute)(
 const QNetworkRequest::Attribute AttributeLanguage = (QNetworkRequest::Attribute)(QNetworkRequest::User + 2);
 const QNetworkRequest::Attribute AttributeText = (QNetworkRequest::Attribute)(QNetworkRequest::User + 3);
 const QNetworkRequest::Attribute AttributeSubTicket = (QNetworkRequest::Attribute)(QNetworkRequest::User + 4);
-
+/*!
+ * \brief GrammarCheckLanguageToolSOAP::check
+ * Place data to be checked on LT-Server
+ * \param ticket
+ * \param subticket
+ * \param language
+ * \param text
+ */
 void GrammarCheckLanguageToolSOAP::check(uint ticket, int subticket, const QString &language, const QString &text)
 {
+    if (!nam) {
+		nam = new QNetworkAccessManager();
+		connect(nam, SIGNAL(finished(QNetworkReply *)), SLOT(finished(QNetworkReply *)));
+	}
+
 	REQUIRE(nam);
 
 	QString lang = language;
 	if (languagesCodesFail.contains(lang) && lang.contains('-'))
 		lang = lang.left(lang.indexOf('-'));
 
-	if (connectionAvailability == 0) {
+	if (connectionAvailability == Unknown) {
 		if (firstRequest) firstRequest = false;
 		else {
 			delayedRequests << CheckRequestBackend(ticket, subticket, lang, text);
@@ -570,34 +624,48 @@ void GrammarCheckLanguageToolSOAP::check(uint ticket, int subticket, const QStri
 
 	nam->post(req, post);
 }
-
+/*!
+ * \brief GrammarCheckLanguageToolSOAP::shutdown
+ * shutdown LT-Server
+ */
 void GrammarCheckLanguageToolSOAP::shutdown()
 {
 	if (javaProcess) {
 		javaProcess->terminate();
 		javaProcess->deleteLater();
 	}
-	connectionAvailability = -2;
+	connectionAvailability = Terminated;
+	if (nam) {
+		nam->deleteLater();
+		nam = 0;
+	}
 }
-
+/*!
+ * \brief GrammarCheckLanguageToolSOAP::finished
+ * Slot for postprocessing LT data
+ * \param nreply
+ */
 void GrammarCheckLanguageToolSOAP::finished(QNetworkReply *nreply)
 {
-	if (connectionAvailability == -2) return; //shutting down
+	if (connectionAvailability == Terminated) return;  // shutting down
+	if (connectionAvailability == Broken) return;  // don't continue if failed before
+	if (nam != sender()) return; //safety check, in case nam was deleted and recreated
 
 	uint ticket = nreply->request().attribute(AttributeTicket).toUInt();
 	int subticket = nreply->request().attribute(AttributeSubTicket).toInt();
 	QString text = nreply->request().attribute(AttributeText).toString();
-	QByteArray reply = nreply->readAll();
 	int status = nreply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
 
 	//qDebug() << status << ": " << reply;
 
 	if (status == 0) {
 		//no response
-		connectionAvailability = -1; //assume no backend
+		connectionAvailability = Broken; //assume no backend
 		tryToStart();
-		if (connectionAvailability == -1) {
+		if (connectionAvailability == Broken) {
 			if (delayedRequests.size()) delayedRequests.clear();
+			nam->deleteLater(); // shutdown unnecessary network manager (Bug 1717/1738)
+			nam = 0;
 			return; //confirmed: no backend
 		}
 		//there might be a backend now, but we still don't have the results
@@ -607,6 +675,8 @@ void GrammarCheckLanguageToolSOAP::finished(QNetworkReply *nreply)
 		return;
 	}
 
+	QByteArray reply = nreply->readAll();
+
 	if (status == 500 && reply.contains("language code") && reply.contains("IllegalArgumentException")) {
 		QString lang = nreply->request().attribute(AttributeLanguage).toString();
 		if (lang.contains('-')) {
@@ -616,7 +686,7 @@ void GrammarCheckLanguageToolSOAP::finished(QNetworkReply *nreply)
 		return;
 	}
 
-	connectionAvailability = 1;
+	connectionAvailability = WorkedAtLeastOnce;
 
 	QDomDocument dd;
 	dd.setContent(reply);
