@@ -10,6 +10,9 @@
 class LatexStyleParser : public SafeThread
 {
 	Q_OBJECT
+#ifndef QT_NO_DEBUG
+	friend class LatexStyleParserTest;
+#endif
 
 public:
 	explicit LatexStyleParser(QObject *parent = 0, QString baseDirName = "", QString kpsecmd = "");
@@ -20,10 +23,12 @@ public:
 protected:
 	void run();
 
-	QStringList readPackage(QString fn, QStringList &parsedPackages);
-	QStringList readPackageTexDef(QString fn);
-	QStringList readPackageTracing(QString fn);
-	QString kpsewhich(QString name, QString dirName = "");
+	QString makeArgString(int count, bool withOptional=false) const;
+	QStringList parseLine(const QString &line, bool &inRequirePackage, QStringList &parsedPackages, const QString &fileName) const;
+	QStringList readPackage(QString fileName, QStringList &parsedPackages) const;
+	QStringList readPackageTexDef(QString fn) const;
+	QStringList readPackageTracing(QString fn) const;
+	QString kpsewhich(QString name, QString dirName = "") const;
 
 signals:
 	void scanCompleted(QString package);
