@@ -258,6 +258,7 @@ void QEditorTest::foldedText(){
 	else if (operation=="unindent") editor->unindentSelection();
 	else if (operation=="comment") editor->commentSelection();
 	else if (operation=="uncomment") editor->uncommentSelection();
+	else if (operation=="togglecomment") editor->toggleCommentSelection();
 	else qFatal("invalid operation");
 	QEQUAL(editor->document()->text(), newEditorText);
 	for (int i=0;i<editor->document()->lines();i++)
@@ -626,6 +627,18 @@ void QEditorTest::indentation_data(){
 		<< "  \\begin{abc}\n    abcdef\n  \\end{abc}"
 		<< "   hel  \\begin{abc}\n       abcdef\n     \\end{abc}lo\nworld\n";
 
+    QTest::newRow("block indentation multiline")
+        << "   hello\nworld\n"
+        << false << 0 << 6 << -1 << -1
+        << "\\begin{abc}\n    abcdef\n sdfsdf\n \\end{abc}"
+        << "   hel\\begin{abc}\n   \tabcdef\n   \tsdfsdf\n   \\end{abc}lo\nworld\n";
+
+    QTest::newRow("block indentation nested")
+        << "   \n"
+        << false << 0 << 3 << -1 << -1
+        << "{\n{\nabcdef\nsdfsdf\n}\n}"
+        << "   {\n   \t{\n   \t\tabcdef\n   \t\tsdfsdf\n   \t}\n   }\n";
+
 	QTest::newRow("block indentation + 3 space")
 		<< "   hello\nworld\n"
 		<< false << 0 << 6 << -1 << -1
@@ -684,7 +697,7 @@ void QEditorTest::indentation_data(){
 		<< "A\nB"
 		<< false << 1 << 0 << -1 << -1
 		<< "\\cmd{\\begin{env}\nTEXT\n\\end{env}}\nMORE\n"
-		<< "\\cmd{\\begin{env}\n\t\tTEXT\n\\end{env}}\nMORE\nB";
+        << "A\n\\cmd{\\begin{env}\n\t\tTEXT\n\\end{env}}\nMORE\nB";
 
 	QTest::newRow("pasting non-indented text with newline at end weak")
 		<< "\tfoo\n\tbar\n"
@@ -777,9 +790,9 @@ void QEditorTest::indentation(){
 	QDocumentCursor c=editor->document()->cursor(line,col,anchorLine,anchorCol);
 	editor->insertText(c, insert);
 
-	QEXPECT_FAIL("2 openings and closings per line", "issue 1335", Continue);
-	QEXPECT_FAIL("3 openings and closings per line", "issue 1335", Continue);
-	QEXPECT_FAIL("multiple closings with unindent on a line", "issue 1335", Continue);
+    //QEXPECT_FAIL("2 openings and closings per line", "issue 1335", Continue);
+    //QEXPECT_FAIL("3 openings and closings per line", "issue 1335", Continue);
+    //QEXPECT_FAIL("multiple closings with unindent on a line", "issue 1335", Continue);
 	QEQUAL(editor->document()->text(), result);
 }
 
